@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,14 +12,12 @@
 #
 ##############################################################################
 """Resource base class and AbsoluteURL adapter
-
-$Id: resource.py 103276 2009-08-27 14:31:59Z nadako $
 """
+import zope.component.hooks
 from zope.component import adapts, getMultiAdapter, queryMultiAdapter
 from zope.interface import implements, implementsOnly
 from zope.location import Location
 from zope.publisher.interfaces.browser import IBrowserRequest
-from zope.site.hooks import getSite
 from zope.traversing.browser.interfaces import IAbsoluteURL
 import zope.traversing.browser.absoluteurl
 
@@ -54,7 +52,7 @@ class AbsoluteURL(zope.traversing.browser.absoluteurl.AbsoluteURL):
         if name.startswith('++resource++'):
             name = name[12:]
 
-        site = getSite()
+        site = zope.component.hooks.getSite()
         base = queryMultiAdapter((site, self.request), IAbsoluteURL,
             name="resource")
         if base is None:
