@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,21 +12,19 @@
 #
 ##############################################################################
 """Support for tests that need a simple site to be provided.
-
-$Id: support.py 103102 2009-08-23 11:48:50Z nadako $
 """
 
 import zope.component
-import zope.location.interfaces
+import zope.component.hooks
+import zope.component.interfaces
 from zope.interface import implements
 from zope.traversing.interfaces import IContainmentRoot
 
-from zope.site.hooks import setSite
 import zope.browserresource.resource
 
 class Site:
 
-    implements(zope.location.interfaces.ISite, IContainmentRoot)
+    implements(zope.component.interfaces.ISite, IContainmentRoot)
 
     def getSiteManager(self):
         return zope.component.getGlobalSiteManager()
@@ -38,10 +36,10 @@ class SiteHandler(object):
 
     def setUp(self):
         super(SiteHandler, self).setUp()
-        setSite(site)
+        zope.component.hooks.setSite(site)
         zope.component.provideAdapter(
             zope.browserresource.resource.AbsoluteURL)
 
     def tearDown(self):
-        setSite()
+        zope.component.hooks.setSite()
         super(SiteHandler, self).tearDown()
