@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,11 @@
 #
 ##############################################################################
 """Test Browser Resources
-
-$Id: test_resources.py 103102 2009-08-23 11:48:50Z nadako $
 """
+
+import doctest
 import unittest
-from zope.testing import cleanup, doctest
+from zope.testing import cleanup
 
 def setUp(test):
     cleanup.setUp()
